/*
Licensed under GNU LGPL
*/

/********************************************************************************
** Form generated from reading UI file 'configui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUI_H
#define UI_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "sonnet/dictionarycombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SonnetConfigUI
{
public:
    QGridLayout *gridLayout;
    QLabel *nobackendfound;
    QLabel *textLabel1;
    Sonnet::DictionaryComboBox *m_langCombo;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout;
    QListWidget *languageList;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_autodetectLanguage;
    QCheckBox *kcfg_backgroundCheckerEnabled;
    QCheckBox *kcfg_checkerEnabledByDefault;
    QCheckBox *kcfg_skipUppercase;
    QCheckBox *kcfg_skipRunTogether;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *ignoredWordsLayout;
    QListWidget *ignoreListWidget;
    QLineEdit *newIgnoreEdit;
    QPushButton *addButton;
    QVBoxLayout *removeButtonLayout;
    QPushButton *removeButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SonnetConfigUI)
    {
        if (SonnetConfigUI->objectName().isEmpty())
            SonnetConfigUI->setObjectName("SonnetConfigUI");
        SonnetConfigUI->resize(700, 833);
        gridLayout = new QGridLayout(SonnetConfigUI);
        gridLayout->setObjectName("gridLayout");
        nobackendfound = new QLabel(SonnetConfigUI);
        nobackendfound->setObjectName("nobackendfound");
        QFont font;
        font.setBold(true);
        font.setItalic(true);
        nobackendfound->setFont(font);
        nobackendfound->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout->addWidget(nobackendfound, 0, 0, 1, 2);

        textLabel1 = new QLabel(SonnetConfigUI);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        m_langCombo = new Sonnet::DictionaryComboBox(SonnetConfigUI);
        m_langCombo->setObjectName("m_langCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_langCombo->sizePolicy().hasHeightForWidth());
        m_langCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_langCombo, 1, 1, 1, 1);

        groupBox1 = new QGroupBox(SonnetConfigUI);
        groupBox1->setObjectName("groupBox1");
        groupBox1->setFlat(true);
        vboxLayout = new QVBoxLayout(groupBox1);
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        languageList = new QListWidget(groupBox1);
        languageList->setObjectName("languageList");

        vboxLayout->addWidget(languageList);


        gridLayout->addWidget(groupBox1, 2, 0, 1, 2);

        groupBox2 = new QGroupBox(SonnetConfigUI);
        groupBox2->setObjectName("groupBox2");
        groupBox2->setFlat(true);
        gridLayout1 = new QGridLayout(groupBox2);
        gridLayout1->setSpacing(0);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        kcfg_autodetectLanguage = new QCheckBox(groupBox2);
        kcfg_autodetectLanguage->setObjectName("kcfg_autodetectLanguage");

        gridLayout1->addWidget(kcfg_autodetectLanguage, 2, 0, 1, 1);

        kcfg_backgroundCheckerEnabled = new QCheckBox(groupBox2);
        kcfg_backgroundCheckerEnabled->setObjectName("kcfg_backgroundCheckerEnabled");

        gridLayout1->addWidget(kcfg_backgroundCheckerEnabled, 3, 0, 1, 1);

        kcfg_checkerEnabledByDefault = new QCheckBox(groupBox2);
        kcfg_checkerEnabledByDefault->setObjectName("kcfg_checkerEnabledByDefault");

        gridLayout1->addWidget(kcfg_checkerEnabledByDefault, 4, 0, 1, 1);

        kcfg_skipUppercase = new QCheckBox(groupBox2);
        kcfg_skipUppercase->setObjectName("kcfg_skipUppercase");

        gridLayout1->addWidget(kcfg_skipUppercase, 5, 0, 1, 1);

        kcfg_skipRunTogether = new QCheckBox(groupBox2);
        kcfg_skipRunTogether->setObjectName("kcfg_skipRunTogether");

        gridLayout1->addWidget(kcfg_skipRunTogether, 6, 0, 1, 1);


        gridLayout->addWidget(groupBox2, 3, 0, 1, 2);

        groupBox = new QGroupBox(SonnetConfigUI);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        ignoredWordsLayout = new QGridLayout();
        ignoredWordsLayout->setObjectName("ignoredWordsLayout");
        ignoreListWidget = new QListWidget(groupBox);
        ignoreListWidget->setObjectName("ignoreListWidget");

        ignoredWordsLayout->addWidget(ignoreListWidget, 1, 0, 1, 1);

        newIgnoreEdit = new QLineEdit(groupBox);
        newIgnoreEdit->setObjectName("newIgnoreEdit");

        ignoredWordsLayout->addWidget(newIgnoreEdit, 0, 0, 1, 1);

        addButton = new QPushButton(groupBox);
        addButton->setObjectName("addButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addButton->setIcon(icon);

        ignoredWordsLayout->addWidget(addButton, 0, 1, 1, 1);

        removeButtonLayout = new QVBoxLayout();
        removeButtonLayout->setObjectName("removeButtonLayout");
        removeButton = new QPushButton(groupBox);
        removeButton->setObjectName("removeButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        removeButton->setIcon(icon1);

        removeButtonLayout->addWidget(removeButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        removeButtonLayout->addItem(verticalSpacer);


        ignoredWordsLayout->addLayout(removeButtonLayout, 1, 1, 1, 1);


        verticalLayout->addLayout(ignoredWordsLayout);


        gridLayout->addWidget(groupBox, 4, 0, 1, 2);


        retranslateUi(SonnetConfigUI);

        QMetaObject::connectSlotsByName(SonnetConfigUI);
    } // setupUi

    void retranslateUi(QWidget *SonnetConfigUI)
    {
        nobackendfound->setText(QCoreApplication::translate("SonnetConfigUI", "No backend like hunspell/aspell/myspell installed", nullptr));
        textLabel1->setText(QCoreApplication::translate("SonnetConfigUI", "Default language:", nullptr));
        groupBox1->setTitle(QCoreApplication::translate("SonnetConfigUI", "Preferred Languages", nullptr));
#if QT_CONFIG(tooltip)
        languageList->setToolTip(QCoreApplication::translate("SonnetConfigUI", "Choose your preferred languages", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox2->setTitle(QCoreApplication::translate("SonnetConfigUI", "Options", nullptr));
        kcfg_autodetectLanguage->setText(QCoreApplication::translate("SonnetConfigUI", "Enable autodetection of &language", nullptr));
        kcfg_backgroundCheckerEnabled->setText(QCoreApplication::translate("SonnetConfigUI", "Enable &background spellchecking", nullptr));
        kcfg_checkerEnabledByDefault->setText(QCoreApplication::translate("SonnetConfigUI", "&Automatic spell checking enabled by default", nullptr));
        kcfg_skipUppercase->setText(QCoreApplication::translate("SonnetConfigUI", "Skip all &uppercase words", nullptr));
        kcfg_skipRunTogether->setText(QCoreApplication::translate("SonnetConfigUI", "S&kip run-together words", nullptr));
        groupBox->setTitle(QCoreApplication::translate("SonnetConfigUI", "Ignored Words", nullptr));
        addButton->setText(QCoreApplication::translate("SonnetConfigUI", "&Add", nullptr));
        removeButton->setText(QCoreApplication::translate("SonnetConfigUI", "&Remove", nullptr));
        (void)SonnetConfigUI;
    } // retranslateUi

};

namespace Ui {
    class SonnetConfigUI: public Ui_SonnetConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGUI_H
