/****************************************************************************
** Meta object code from reading C++ file 'spellcheckhighlighter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../sonnet-6.25.0/src/quick/spellcheckhighlighter.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'spellcheckhighlighter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SpellcheckHighlighterE_t {};
} // unnamed namespace

template <> constexpr inline auto SpellcheckHighlighter::qt_create_metaobjectdata<qt_meta_tag_ZN21SpellcheckHighlighterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpellcheckHighlighter",
        "QML.Element",
        "auto",
        "documentChanged",
        "",
        "cursorPositionChanged",
        "selectionStartChanged",
        "selectionEndChanged",
        "wordIsMisspelledChanged",
        "wordUnderMouseChanged",
        "changeCursorPosition",
        "start",
        "end",
        "activeChanged",
        "misspelledColorChanged",
        "autoDetectLanguageDisabledChanged",
        "automaticChanged",
        "currentLanguageChanged",
        "description",
        "setCurrentLanguage",
        "language",
        "slotAutoDetection",
        "slotRehighlight",
        "suggestions",
        "position",
        "max",
        "ignoreWord",
        "word",
        "addWordToDictionary",
        "replaceWord",
        "at",
        "isWordMisspelled",
        "document",
        "QQuickTextDocument*",
        "cursorPosition",
        "selectionStart",
        "selectionEnd",
        "wordIsMisspelled",
        "wordUnderMouse",
        "misspelledColor",
        "QColor",
        "currentLanguage",
        "spellCheckerFound",
        "active",
        "automatic",
        "autoDetectLanguageDisabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionStartChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEndChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wordIsMisspelledChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wordUnderMouseChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeCursorPosition'
        QtMocHelpers::SignalData<void(int, int)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'misspelledColorChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoDetectLanguageDisabledChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentLanguageChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'setCurrentLanguage'
        QtMocHelpers::SlotData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'slotAutoDetection'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRehighlight'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'suggestions'
        QtMocHelpers::MethodData<QStringList(int, int)>(23, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Method 'suggestions'
        QtMocHelpers::MethodData<QStringList(int)>(23, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList, {{
            { QMetaType::Int, 24 },
        }}),
        // Method 'ignoreWord'
        QtMocHelpers::MethodData<void(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'addWordToDictionary'
        QtMocHelpers::MethodData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'replaceWord'
        QtMocHelpers::MethodData<void(const QString &, int)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Int, 30 },
        }}),
        // Method 'replaceWord'
        QtMocHelpers::MethodData<void(const QString &)>(29, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'isWordMisspelled'
        QtMocHelpers::MethodData<bool(const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'document'
        QtMocHelpers::PropertyData<QQuickTextDocument*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'selectionStart'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectionEnd'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'wordIsMisspelled'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'wordUnderMouse'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'misspelledColor'
        QtMocHelpers::PropertyData<QColor>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'currentLanguage'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'spellCheckerFound'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'automatic'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'autoDetectLanguageDisabled'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SpellcheckHighlighter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SpellcheckHighlighter::staticMetaObject = { {
    QMetaObject::SuperData::link<QSyntaxHighlighter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpellcheckHighlighterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpellcheckHighlighterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SpellcheckHighlighterE_t>.metaTypes,
    nullptr
} };

void SpellcheckHighlighter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpellcheckHighlighter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentChanged(); break;
        case 1: _t->cursorPositionChanged(); break;
        case 2: _t->selectionStartChanged(); break;
        case 3: _t->selectionEndChanged(); break;
        case 4: _t->wordIsMisspelledChanged(); break;
        case 5: _t->wordUnderMouseChanged(); break;
        case 6: _t->changeCursorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->activeChanged(); break;
        case 8: _t->misspelledColorChanged(); break;
        case 9: _t->autoDetectLanguageDisabledChanged(); break;
        case 10: _t->automaticChanged(); break;
        case 11: _t->currentLanguageChanged(); break;
        case 12: _t->activeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->setCurrentLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->slotAutoDetection(); break;
        case 15: _t->slotRehighlight(); break;
        case 16: { QStringList _r = _t->suggestions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 17: { QStringList _r = _t->suggestions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->ignoreWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->addWordToDictionary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->replaceWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 21: _t->replaceWord((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: { bool _r = _t->isWordMisspelled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::documentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::cursorPositionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::selectionStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::selectionEndChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::wordIsMisspelledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::wordUnderMouseChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)(int , int )>(_a, &SpellcheckHighlighter::changeCursorPosition, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::activeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::misspelledColorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::autoDetectLanguageDisabledChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::automaticChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)()>(_a, &SpellcheckHighlighter::currentLanguageChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SpellcheckHighlighter::*)(const QString & )>(_a, &SpellcheckHighlighter::activeChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickTextDocument* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickTextDocument**>(_v) = _t->quickDocument(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorPosition(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->selectionStart(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->selectionEnd(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->wordIsMisspelled(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->wordUnderMouse(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->misspelledColor(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->currentLanguage(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->spellCheckerFound(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->automatic(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->autoDetectLanguageDisabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setQuickDocument(*reinterpret_cast<QQuickTextDocument**>(_v)); break;
        case 1: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectionStart(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSelectionEnd(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setMisspelledColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setAutomatic(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setAutoDetectLanguageDisabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SpellcheckHighlighter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpellcheckHighlighter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpellcheckHighlighterE_t>.strings))
        return static_cast<void*>(this);
    return QSyntaxHighlighter::qt_metacast(_clname);
}

int SpellcheckHighlighter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSyntaxHighlighter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void SpellcheckHighlighter::documentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SpellcheckHighlighter::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SpellcheckHighlighter::selectionStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SpellcheckHighlighter::selectionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SpellcheckHighlighter::wordIsMisspelledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SpellcheckHighlighter::wordUnderMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SpellcheckHighlighter::changeCursorPosition(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void SpellcheckHighlighter::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SpellcheckHighlighter::misspelledColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SpellcheckHighlighter::autoDetectLanguageDisabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SpellcheckHighlighter::automaticChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SpellcheckHighlighter::currentLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void SpellcheckHighlighter::activeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
